@echo off

rem SmartCAM Process Model File Association utility
rem 28-Apr-2008
rem This utility works with SmartCAM v12.5.1 or later. Earlier releases
rem of SmartCAM may not work.
rem
rem This utility is for users with multiple SmartCAM NC applications. If you
rem only have a single SmartCAM application you do not need this batch file.
rem You can associate the Process Model files directly to your application.
rem 
rem Once this Batch File has been configured, you can associate the
rem SmartCAM Process Model file extension (.sh2, .sh3, .pm4, .pm5) to this
rem batch file and it will launch the correct application and load the
rem associated Process Model file when you double-click on the file from
rem Windows Explorer.
rem
rem Refer to your Windows Manual or Online Help for instructions on how to
rem create File Extension associations for your version of Windows.
rem
rem To configure this batch file, complete the following.
rem
rem Modify the SCDRIVE environment variable to contain the drive letter,
rem and colon, for the drive on which SmartCAM is installed.
rem
rem Modify the SCPATH variable to point to the full path to the SmartCAM
rem SYSTEM directory.
rem
rem This batch file works by reading the associated Process Model file and
rem extracting a build string (this is handled by the findstr blocks below).
rem The string tells which SmartCAM application was used to create the file.
rem
rem The final configuration is to modify these findstr blocks and point the
rem SCAPP variable to the SmartCAM application you would like to use to open
rem and edit these files.
rem
rem For example, if you own Advanced Milling, you will want to point
rem the 'findstr "Production_Milling" ...' block to AMILL.EXE instead of
rem PMILL.EXE. This way, files containing the 'Production_Milling' build
rem stamp will be opened by Advanced Milling on your system.
rem
rem Do this for all the 'findstr' blocks.
rem
rem After the above steps, configuration is complete.

rem Static Paths
rem Edit these variables to set appropriate path information
set SCDRIVE=C:
set SCPATH=\Program Files\SmartCAM\SmartCAMv15\SYSTEM\
set runfile=%1

rem Change to correct drive and path to launch application
%SCDRIVE%
cd %SCPATH%

findstr "Production_Milling" %runfile%
if not errorlevel 1 set SCAPP=pmill.exe

findstr "Advanced_Milling" %runfile%
if not errorlevel 1 set SCAPP=amill.exe

findstr "Advanced_Production_Milling" %runfile%
if not errorlevel 1 set SCAPP=amill.exe

findstr "Form_Machining" %runfile%
if not errorlevel 1 set SCAPP=ffm.exe

findstr "Production_Turning" %runfile%
if not errorlevel 1 set SCAPP=pturn.exe

findstr "Advanced_Turning" %runfile%
if not errorlevel 1 set SCAPP=aturn.exe

findstr "Advanced_Fabrication" %runfile%
if not errorlevel 1 set SCAPP=afab.exe

findstr "Advanced_Wire_EDM" %runfile%
if not errorlevel 1 set SCAPP=awedm.exe

findstr "Cam_Connection" %runfile%
if not errorlevel 1 set SCAPP=ffm.exe


start %SCAPP% %runfile%
cls
